package com.ruoyi.project.training.bccnew.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.training.bccnew.mapper.TTsFtplanTmplMapper;
import com.ruoyi.project.training.bccnew.domain.TTsFtplanTmpl;
import com.ruoyi.project.training.bccnew.service.ITTsFtplanTmplService;

/**
 * 芳烃培训模版Service业务层处理
 *
 * @author ssy
 * @date 2024-06-13
 */
@Service
public class TTsFtplanTmplServiceImpl implements ITTsFtplanTmplService
{
    @Autowired
    private TTsFtplanTmplMapper tTsFtplanTmplMapper;

    /**
     * 查询芳烃培训模版
     *
     * @param id 芳烃培训模版ID
     * @return 芳烃培训模版
     */
    @Override
    public TTsFtplanTmpl selectTTsFtplanTmplById(Long id)
    {
        return tTsFtplanTmplMapper.selectTTsFtplanTmplById(id);
    }

    /**
     * 查询芳烃培训模版列表
     *
     * @param tTsFtplanTmpl 芳烃培训模版
     * @return 芳烃培训模版
     */
    @Override
    public List<TTsFtplanTmpl> selectTTsFtplanTmplList(TTsFtplanTmpl tTsFtplanTmpl)
    {
        return tTsFtplanTmplMapper.selectTTsFtplanTmplList(tTsFtplanTmpl);
    }

    /**
     * 新增芳烃培训模版
     *
     * @param tTsFtplanTmpl 芳烃培训模版
     * @return 结果
     */
    @Override
    public int insertTTsFtplanTmpl(TTsFtplanTmpl tTsFtplanTmpl)
    {
        return tTsFtplanTmplMapper.insertTTsFtplanTmpl(tTsFtplanTmpl);
    }

    /**
     * 修改芳烃培训模版
     *
     * @param tTsFtplanTmpl 芳烃培训模版
     * @return 结果
     */
    @Override
    public int updateTTsFtplanTmpl(TTsFtplanTmpl tTsFtplanTmpl)
    {
        return tTsFtplanTmplMapper.updateTTsFtplanTmpl(tTsFtplanTmpl);
    }

    /**
     * 批量删除芳烃培训模版
     *
     * @param ids 需要删除的芳烃培训模版ID
     * @return 结果
     */
    @Override
    public int deleteTTsFtplanTmplByIds(Long[] ids)
    {
        return tTsFtplanTmplMapper.deleteTTsFtplanTmplByIds(ids);
    }

    /**
     * 删除芳烃培训模版信息
     *
     * @param id 芳烃培训模版ID
     * @return 结果
     */
    @Override
    public int deleteTTsFtplanTmplById(Long id)
    {
        return tTsFtplanTmplMapper.deleteTTsFtplanTmplById(id);
    }
}
